/*
 * Paraselene
 * Copyright (c) 2009  Akira Terasaki
 * このファイルは同梱されているLicense.txtに定めた条件に同意できる場合にのみ
 * 利用可能です。
 */
package paraselene.mockup;


import java.io.*;

public class SourceHead {
	private static String head = "";

	public static void init( File f ) throws FileNotFoundException, IOException {
		StringBuilder	buf = new StringBuilder();
		BufferedReader	br = new BufferedReader(
			new InputStreamReader( new FileInputStream( f ) )
		);
		while( true ) {
			String	line = br.readLine();
			if ( line == null )	break;
			buf = buf.append( line );
			buf = buf.append( LineSeparator.getUse() );
		}
		br.close();
		head = buf.toString();
	}

	public static String getHead() {
		return head;
	}
}

